Simulation Module
=================

The simulation module will provide stochastic modeling tools.

.. automodule:: actuneo.simulation
   :members:
   :undoc-members:
   :show-inheritance:

.. note::
   This module is under development. Contributions are welcome!

Planned Features
----------------

* Monte Carlo simulation
* Scenario generation
* Stochastic mortality models
* Economic scenario generators
* Risk modeling
* Sensitivity analysis

